Renames a version-controlled file with svn mv and updates every reference to its path in the file and origin columns of QClog.csv.

Paths are resolved relative to the root of the QC log, including when the function is called from a subdirectory.

logRename(.filepath, .new_filepath)

Arguments

.filepath

Current path of the file to rename.

.new_filepath

New path for the file.

Value

Invisibly returns the number of rows changed in QClog.csv.

Examples

if (FALSE) { # \dontrun{
logRename("script/old-name.R", "script/new-name.R")
} # }