Summarize the review log associated with a particular directory.
logSummary(directory = getwd())A data frame containing one row per file. Columns include file,
origin, revf, headf, revo, heado,
reviewer, and time.
Whereas the review log can have any number of records for the same file, the summary reduces the data to one record per file. It is an error if any element of the file column is missing.
The log is read, then sorted on file, revision, time. The last record for each file is retained.
The output includes the latest revisions for the file and origin, plus the reviewer and time information. Times are returned as character strings in GMT.
with_demoRepo({
logSummary()
})
#> file origin revf headf revo heado reviewer
#> 7 script/combine-da.R script/combine-da.R 1 1 1 1 anderson
#> 5 script/data-assembly.R script/data-assembly.R 1 5 1 5 anderson
#> 4 script/examp-txt.txt script/examp-txt.txt 0 1 0 1 anyone
#> 6 script/pk/load-spec.R script/pk/load-spec.R 1 4 1 4 anderson
#> time
#> 7 2026-08-20 13:36:18.7864766120911 GMT
#> 5 2026-08-20 13:36:18.7382709980011 GMT
#> 4 2026-08-20 13:36:18.6723258495331 GMT
#> 6 2026-08-20 13:36:18.7598886489868 GMT