Compares the local version of a script with the most recent QCed version. The output will appear in the viewer and only rows where there have been additions, deletions or modifications in the script will be shown.

diffQced(
  .file,
  .side_by_side = TRUE,
  .ignore_white_space = FALSE,
  .display_entire_file = FALSE,
  .open_file = FALSE
)

Arguments

.file

file path from working directory

.side_by_side

Logical. Should diffs be displayed side by side?

.ignore_white_space

Logical. Should white space be ignored?

.display_entire_file

Logical. Should the entire file be displayed?

.open_file

Logical. Should the file open after generating diff?

Details

The file must be part of an SVN working copy that is in sync with the repo. If the local copy is out of date or has local modifications, the function will stop and prompt you to update or review local changes.

Examples

with_demoRepo({
  diffQced("script/data-assembly.R")
})
#> 
#> ── QC diff for: script/data-assembly.R ──
#> 
#> Last QCed Revision: 1
#> Last Author: anderson
#> < data-assembly.R: Revision 1            > data-assembly.R: Local               
#> @@ 1,5 @@                                @@ 1,10 @@                             
#>   library(tidyverse)                       library(tidyverse)                   
#> ~                                        > source(here::here("script", "data-ass
#> ~                                        : embly", "da-functions.R"))           
#>   src_abc <- mrgda::read_src_dir(here::    src_abc <- mrgda::read_src_dir(here::
#>   here("data", "source", "STUDY-ABC"))     here("data", "source", "STUDY-ABC")) 
#>   derived <- list(sl = list(),tv = list    derived <- list(sl = list(),tv = list
#>   ())                                      ())                                  
#>   dm_0 <- src_abc$dm %>% filter(ACTARM     dm_0 <- src_abc$dm %>% filter(ACTARM 
#>   != "Screen Failure")                     != "Screen Failure")                 
#>   derived$sl$dm <- dm_0                    derived$sl$dm <- dm_0                
#> ~                                        > pk_0 <- src_abc$pc %>% filter(PCTEST 
#> ~                                        : == "TEST OF INTEREST")               
#> ~                                        > derived$tv$pc <- pk_0                
#> ~                                        > ex_1 <- src_abc$ex %>% filter(EXTRT =
#> ~                                        : = "DRUG OF INTEREST")                
#> ~                                        > derived$tv$dosing <- ex_1